@@ -59,7 +59,7 @@ def main():
         help="Optional substring that must be present in a test to run."
     )
 
-    parser.add_argument("--exclude_string", type=str, nargs="?",
+    parser.add_argument("--exclude_string", type=str, action="append", nargs="*",
         help="Optional substring that must be absent in a test to run."
     )
 
@@ -119,6 +119,10 @@ def main():
         help="If specified, the module.function() will be called before run. Good for log setup. In form full_path/to.py:func()",
     )
 
+    parser.add_argument("--preview", action="store_true",
+        help="Show tests that would run.",
+    )
+
     # fmt: on
 
     kwargs = vars(parser.parse_args())
@@ -127,7 +131,6 @@ def main():
         print(__version__)
         sys.exit(0)
 
-
     # zest needs a way to ask the application to setup logging
     hook = kwargs.get("hook_start")
     if hook is not None:
